# McAfee Active Response (MAR) DXL Python Client Library
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

## Overview

The [McAfee Active Response](http://www.mcafee.com/us/products/endpoint-threat-defense-response.aspx) (MAR) DXL Python
client library provides a high level wrapper for the MAR [Data Exchange Layer](http://www.mcafee.com/us/solutions/data-exchange-layer.aspx)
(DXL) API.

The purpose of this library is to allow users to perform MAR searches without having to focus
on lower-level details such as MAR-specific DXL topics and message formats.

## Documentation

See the [Wiki](https://github.com/opendxl/opendxl-mar-client-python/wiki) for an overview of the McAfee Active Response (MAR) DXL Python client library and examples.

See the [McAfee Active Response (MAR) DXL Python Client Library Documentation](https://opendxl.github.io/opendxl-mar-client-python/pydoc) for
installation instructions, API documentation, and examples.

## Installation

To start using the McAfee Active Response (MAR) DXL Python Client Library:

* Download the [Latest Release](https://github.com/opendxl/opendxl-mar-client-python/releases/latest)
* Extract the release .zip file
* View the `README.html` file located at the root of the extracted files.
  * The `README` links to the documentation which includes installation instructions, API details, and samples.
  * The SDK documentation is also available on-line [here](https://opendxl.github.io/opendxl-mar-client-python/pydoc).

## Bugs and Feedback

For bugs, questions and discussions please use the [Github Issues](https://github.com/opendxl/opendxl-mar-client-python/issues).

## LICENSE

Copyright 2016 McAfee, Inc.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
